@@ -55,7 +55,7 @@ class Button(tkButton):
                  rinterval=2000, # repeat interval
                  state="normal", # default state normal disable or active
                  takefocus=1, # set button property if button can take focus or not
-                 text="ntk button", # button text value
+                 text="Button", # button text value
                  tvar=None, # text variable to set and get dynamic value
                  underline=99, # underline position for text chars
                  width=16, # button width
@@ -140,3 +140,9 @@ class Button(tkButton):
                                     fg=color(afg) if self['state'] == 'active' else color(fg)
                                 )
                             )
+
+    def config(self, **kwargs):
+        super(Button, self).config(kwargs)
+
+        for key, value in kwargs.items():
+            setattr(self, key, value)
