@@ -1,5 +1,6 @@
 # Import Tkinter Entry to use it and modify default
 
+import os
 from ntk.widgets.entry import Entry
 
 # Import all util from ntk.utils
@@ -13,6 +14,10 @@ from ntk.widgets.toplevel import Toplevel
 # Import Tkinter Toplevel to use it for list container
 
 from ntk.widgets.canvas import Canvas
+from ntk.widgets.button import Button
+from ntk.widgets.frame import Frame
+from ntk.widgets.panedwindow import PanedWindow
+from ntk.widgets.image import ImageFile
 
 
 # from ntk.widgets.scroller import Scrollbar
@@ -22,6 +27,7 @@ from ntk.widgets.canvas import Canvas
 
 from ntk.objects import gv
 
+
 class SelectBox(Entry):
 
     # selectbox class can be called for create root tk
@@ -64,16 +70,26 @@ class SelectBox(Entry):
 
     def __init__(self,
                  root, # root is a master window to place this entry into it
-                 values=['ntk option 1', 'ntk option 2' 'ntk option 3'], # values can be a list or tuple
+                 values=['Values:list/tuple'], # values can be a list or tuple
                  height=10, # height of value list
                  default=True, # default value in entry box
                  selectcommand=False, # to perform when any value is selected
                  bg='#F4F4F4', # background color of select box
                  onclick='', # perform set rule when entry box clicked
+                 boxbg='bg-dark',
                  *args, **kwargs # extra arguments and keyword arguments
             ):
 
-        super(SelectBox, self).__init__(root,
+        self.frame_master = PanedWindow(
+            root, width=0, height=0, bg=boxbg, row=kwargs.get('row', 0), bd=1, padx=kwargs.get('padx', 0),
+            column=kwargs.get('column', 0), orient='horizontal', sashwidth=0, pady=kwargs.get('pady', 0))
+
+        image_file = os.path.join(os.path.dirname(os.path.dirname(__file__)), "arrow.png")
+        image = ImageFile(image_file).main
+
+        kwargs['height'] = 1
+
+        super(SelectBox, self).__init__(self.frame_master,
                                         bg=bg,
                                         abg=kwargs.pop('abg', bg), # background color when entry is active,
                                                                         # it will get default or poped if passed
@@ -88,6 +104,13 @@ class SelectBox(Entry):
                                         *args, **kwargs
                                     )
 
+        self.select_icon = Button(
+            self.frame_master, image=image, text='', compound='right',
+            anchor='e', width=0, height=0, bg=bg, hoverbg=bg, abg=bg, justify='right')
+
+        self.frame_master.add(self)
+        self.frame_master.add(self.select_icon)
+
         # set default value for list is False
 
         self.list = False
@@ -123,6 +146,7 @@ class SelectBox(Entry):
         # because we want to perform show_selection when button clicked
 
         self.bind("<Button-1>", lambda e: self.show_selection(e))
+        self.select_icon.bind("<Button-1>", lambda e: self.show_selection(e))
 
         # bind Key Release event to typed method
         # because we want to perform typed when key released
@@ -143,7 +167,7 @@ class SelectBox(Entry):
                 # if default is bool and it's True
                 # then set default as first item of values list
 
-                default = values[0]
+                default = (values[0]) if len(values) > 0 else "Please select item"
 
             # next set entry value to default value
             # by entry.set(default)
@@ -218,19 +242,19 @@ class SelectBox(Entry):
 
             # set rx as select.winfo_rootx
 
-            rx = self.winfo_rootx()
+            rx = self.frame_master.winfo_rootx()
 
             # set ry as select.winfo_rooty
 
-            ry = self.winfo_rooty()
+            ry = self.frame_master.winfo_rooty()
 
             # set rw as select.winfo_width
 
-            rw = self.winfo_width()
+            rw = self.frame_master.winfo_width()
 
             # set rh as select.winfo_height
 
-            rh = self.winfo_height()
+            rh = self.frame_master.winfo_height()
 
             # set rx as select object attribute
 
@@ -270,6 +294,8 @@ class SelectBox(Entry):
                                  topbar=False # pass topbar parameter as false, it will not contain top bar
                             )
 
+            self.list.transient(self.root)
+
             # next define main list as list body
 
             self.list_body = Canvas(self.list, # root window is select.list
@@ -339,11 +365,11 @@ class SelectBox(Entry):
 
         # set rw as select.winfo_width
 
-        rw = self.winfo_width()
+        rw = self.frame_master.winfo_width()
 
         # set rh as select.winfo_height
 
-        rh = self.winfo_height()
+        rh = self.frame_master.winfo_height()
 
         # let's loop into values list
 
@@ -496,7 +522,7 @@ class SelectBox(Entry):
 
             # check if searched text is matching with this item
 
-            if tx in el:
+            if tx.lower() in el.lower():
 
                 # if searched value is matching with list item
                 # add this item to new values list
